<?php

namespace Drupal\moderated_content_bulk_publish\Plugin\Action;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\node\NodeInterface;

/**
 * Provides an action that can save any entity.
 *
 * @Action(
 *   id = "node_save_moderated_action",
 *   action_label = @Translation("Save moderated content"),
 *   deriver = "Drupal\Core\Action\Plugin\Action\Derivative\EntityChangedActionDeriver",
 * )
 */
class SaveModeratedNodeAction extends RevisionActionBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    if ($this->currentUser->hasPermission('moderated content bulk save content')) {
      $this->getLogger('moderated_content_bulk_publish')->notice("Executing Change Owner content of " . $entity->label());

      $this->adminModeratedContent->setValues($entity, NodeInterface::NOT_PUBLISHED);
      /** @var \Drupal\node\NodeInterface $entity */
      $config = \Drupal::config('moderated_content_bulk_publish.settings');
      $entity = $this->adminModeratedContent->saveContent($config->get('current_translation_only'));

      $msg = 'The node %s has been saved (all translations).';
      if ($config->get('current_translation_only')) {
        $msg = 'The node %s has been saved (only selected translations).';
      }
      return sprintf($msg, $entity->id());
    }
    else {
      $this->messenger()->addWarning(t("You don't have access to execute this operation!"));
      return;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    // It's not necessary to check the changed field access here, because
    // Drupal\Core\Field\ChangedFieldItemList would anyway return 'not allowed'.
    // Also changing the changed field value is only a workaround to trigger an
    // entity resave. Without a field change, this would not be possible.
    /** @var \Drupal\Core\Entity\EntityInterface $object */
    return $object->access('update', $account, $return_as_object);
  }

}
