<?php

namespace Drupal\moderated_content_bulk_publish\Plugin\Action;

/**
 * An example action covering most of the possible options.
 *
 * If type is left empty, action will be selectable for all
 * entity types.
 *
 * @Action(
 *   id = "unpin_content_action",
 *   label = @Translation("Unpin current revision (sticky)"),
 *   type = "node",
 *   confirm = TRUE,
 * )
 */
class UnpinContentAction extends RevisionActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    /*
     * All config resides in $this->configuration.
     * Passed view rows will be available in $this->context.
     * Data about the view used to select results and optionally
     * the batch context are available in $this->context or externally
     * through the public getContext() method.
     * The entire ViewExecutable object  with selected result
     * rows is available in $this->view or externally through
     * the public getView() method.
     */
    if ($this->currentUser->hasPermission('moderated content bulk unpin')) {
      $this->getLogger('moderated_content_bulk_publish')->notice("Executing Unpin content of " . $entity->label());

      $this->adminPin->setValues($entity, $entity->isSticky());
      $config = \Drupal::config('moderated_content_bulk_publish.settings');
      $entity = $this->adminPin->unpin($config->get('current_translation_only'));

      // Check if unpinned
      if ($entity->isSticky()){
        $msg = "Something went wrong, the entity must be unpinned by this point.";
        $this->messenger()->addError(utf8_encode($msg));
        $this->getLogger('moderated_content_bulk_publish')->warning($msg);
        return $msg;
      }
      $msg = 'The node %s has been unset to sticky (all translations).';
      if ($config->get('current_translation_only')) {
        $msg = 'The node %s has been unset to sticky (only selected translations).';
      }
      return sprintf($msg, $entity->id());
    }
    else {
      $this->messenger()->addWarning(t("You don't have access to execute this operation!"));
      return;
    }

  }

}
