<?php

namespace Drupal\moderated_content_bulk_publish\Plugin\Action;

use Drupal\Core\Render\Markup;
use Drupal\node\NodeInterface;

/**
 * An example action covering most of the possible options.
 *
 * If type is left empty, action will be selectable for all
 * entity types.
 *
 * @Action(
 *   id = "unpublish_current_revision_action",
 *   label = @Translation("Unpublish Current Revision"),
 *   type = "node",
 *   confirm = TRUE,
 * )
 */
class UnpublishCurrentRevisionAction extends RevisionActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    /*
     * All config resides in $this->configuration.
     * Passed view rows will be available in $this->context.
     * Data about the view used to select results and optionally
     * the batch context are available in $this->context or externally
     * through the public getContext() method.
     * The entire ViewExecutable object  with selected result
     * rows is available in $this->view or externally through
     * the public getView() method.
     */
    if ($this->currentUser->hasPermission('moderated content bulk unpublish')) {
      $this->getLogger('moderated_content_bulk_publish')->notice("Executing unpublish latest revision of " . $entity->label());

      $this->adminModeratedContent->setValues($entity, NodeInterface::NOT_PUBLISHED);
      $config = \Drupal::config('moderated_content_bulk_publish.settings');
      $entity = $this->adminModeratedContent->unpublish($errorMessage, $markup, $config->get('current_translation_only'));
      if (!isset($entity) && !empty($errorMessage)) {
        $this->messenger()->addWarning(utf8_encode($errorMessage));
        $htmlElement = Markup::create($markup);
        $this->messenger()->addWarning($htmlElement);
        return $errorMessage;
      }

      //Check if published.
      if ($entity->isPublished()){
        $msg = "Something went wrong, the entity must be unpublishd by this point.  Review your content moderation configuration make sure you have unpublish state which sets current revision ??? and try again.";
        $this->messenger()->addError(utf8_encode($msg));
        $this->getLogger('moderated_content_bulk_publish')->warning($msg);
        return $msg;
      }
      $msg = 'The node %s has been set to unpublished moderation state (all translations).';
      if ($config->get('current_translation_only')) {
        $msg = 'The node %s has been set to unpublished moderation state (only selected translations).';
      }
      return sprintf($msg, $entity->id());
    }
    else {
      $this->messenger()->addWarning(t("You don't have access to execute this operation!"));
      return;
    }

  }

}
